@@ -1,11 +1,15 @@
 import fastapi
 
+from starlette.exceptions import HTTPException as StarletteHTTPException
+
 from gaea.database import db
+from gaea.log import logger
 
 
 def get_session(request: fastapi.Request):
     return request.state.session
 
+
 class MiddleWare:
     def __init__(self, db_client=None):
         self.db = db_client
@@ -29,8 +33,13 @@ class MiddleWare:
         try:
             response = await call_next(request)
 
-        except:
+        except fastapi.HTTPException as exc:
             await self.exception_handler()
+            logger.exception("Managed exception happened")
+            raise
+        except Exception as exc:
+            await self.exception_handler()
+            logger.exception("Unexpected exception happened")
             raise
 
         finally:
